@@ -5,10 +5,10 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Vasiliev Ivan <i.vasiliev@technokert.ru>
-# from typing import Any
-#
-# from async_tools import acall
-#
-#
-# async def call_acall_from_async_tools_lib(target: Any) -> Any:
-#     return await acall(target)
+from typing import Any
+
+from async_tools import acall
+
+
+async def call_acall_from_async_tools_lib(target: Any) -> Any:
+    return await acall(target)
